#define NAIPES 4
#define CARTAS 13
#define MAGIC_LEN 4 /* 2 letras, 1 '\n', 1 '\0' */
#define PPMEXT "ppm"

typedef struct {
  unsigned char R, G, B;
} Pixel;

typedef struct {
  unsigned char valor, naipe;
  Pixel *img;
} Carta;

typedef struct {
  char magic[MAGIC_LEN];
  int w, h, maxval;
} Cabecalho;

typedef Carta **Baralho;

typedef char  **Monte;


/* Inicia a  estrutura de dados para conter  as imagens individualizadas
   de cartas. Os parmetros indicam o nome do arquivo com a imagem original
   em PPM, as dimenses de cada carta  na imagem original, o valor da carta
   mais  esquerda, e a ordem dos naipes na imagem (de cima para baixo)
*/
Baralho init(char *imgFile, int cw,  int ch, 
	     char primCarta, char *ordNaipes);

/* Retorna Cabecalho PPM de cada carta */
Cabecalho getDimCarta();

/* Retorna ponteiro para vetor contendo os nomes dos valores
   de cartas.
*/
char *getValores();

/* Retorna ponteiro para vetor contendo os nomes dos naipes
   de cartas.
*/
char *getNaipes();

/* L  a  imagem  do  arquivo principal e preenche a estrutura de dados
   gerada por \textsf{init()}.
*/
Baralho geraBaralho(Baralho  cartas);

/* Gera a imagem PPM de uma carta individual, pronta para uso 
 */
Carta getCarta(char naipe, char valor, Baralho cartas);

/* Gera arquivo com imagem de  uma carta individual em formato PPM. Nome
   do   arquivo  tem   formato   ``valor-naipe.ppm''  (e.g.,   ``A-C.ppm'',
   ``2-P.ppm'', etc.)
*/
void geraCarta(char naipe,  char valor, Baralho cartas);

/* Cria  um monte  vazio (sem  cartas), que  pode ser  preenchido usando
   colocaCarta() e esvaziado com tiraCarta().
*/
Monte criaMonte();

/* Embaralha a ordem das cartas em um monte */
Monte embaralhaMonte(Monte deck);

/* Gera um  vetor contendo todas as 'n' x 52 cartas embaralhadas
   em ordem aleatria.
 */
Monte embaralha(int n, Baralho cartas);

/* Retorna 1 (um) de monte est vazio, 0 (zero) caso contrrio.
*/
int monteVazio(Monte deck);

/* Calcula quantas cartas tem em um monte */
int sizeDeck(Monte deck);

/* Retorna  a primeira carta  de um monte, sem retir-la do topo
   deste.
   Retorna um valor do tipo Carta com membros nulos se o monte 
   no tem mais cartas.
 */
Carta topoMonte(Monte  deck, Baralho baralho);

/* Retorna  a primeira carta  de um monte. Retorna um valor do tipo Carta
   com membros nulos se o monte no tem mais cartas.
 */
Carta tiraCarta(Monte  deck, Baralho baralho);

/* Coloca uma carta no topo de um monte.
 */
Monte colocaCarta(Carta c, Monte deck);

/* Mostra contedo de um monte, do topo ao final,
   mas sem retirar as cartas do monte.
*/
void mostraMonte(Monte deck);

/* Inicia a  estrutura de dados para conter  as imagens individualizadas
   de cartas. Os parmetros indicam o nome do arquivo com a imagem original
   em PPM, as dimenses de cada carta  na imagem original, o valor da carta
   mais  esquerda, e a ordem dos naipes na imagem (de cima para baixo)
*/
Baralho init2(char *imgFile, char primCarta, char *ordNaipes);

/* L uma imagem de carta de arquivo (vide obs. sobre nome de arquivo acima)
   e coloca na estrutura Baralho.
 */
Carta readCarta(char naipe, char valor);

/* A partir de imagens individuais de cartas de baralho, gera uma imagem
   nica contendo todas as cartas, um naipe por linha, 13 cartas em cada linha.
   Os nomes dos arquivos de cartas devem seguir o padro "V-P.ppm".
*/
void gravaBaralho(int w_offset, int h_offset, Baralho  cartas);

